#!/bin/bash

if [ -z "$IPTABLES" ]; then
	IPTABLES="iptables"
fi

# new_chain chainname
function new_chain() {
	$IPTABLES --delete-chain $1 2>/dev/null
	$IPTABLES --new $1
}

IMPORTED="ALLOW ACCEPT PERMIT DENY DROP BLACKHOLE REJECT MASQ MASQUERADE LOG"
# fw_do --{append,insert,etc...} RULE .....
function fw_do {
	local table
	if [ "$2" == "POSTROUTING" ]; then
		table=nat
	else
		table=filter
	fi
	$IPTABLES -t $table $*
}

function apply_policy {
	local TARGET table
	TARGET=$1
	shift
	if [ ! -z "${if}" ]; then
		TARGET=${if}-${TARGET}
	fi
	fw_do --append $TARGET $*
}

# fw_flush [chainname]
function fw_flush {
	if [ "$*" = "" ]; then
		for i in /proc/net/ip_tables_names; do
			$IPTABLES -t $i --flush
		done
	else
		$IPTABLES --flush $*
	fi
}

# fw_policy rulename policy
function fw_policy {
	fw_do --policy $1 $2
}

fw_policy INPUT DROP
fw_output INPUT DROP
fw_forward INPUT DROP

status Configuring host overrides
for i in hosts.d/*.host; do
	substatus $i
	. $i
done

status Configuring interfaces
for i in /etc/linuxserver-firewall/interfaces.d/*.if; do
	if=$(basename $i| sed s/\.if$//)
        substatus $if
	new_chain ${if}-in
	fw_do --append INPUT --in-interface ${if} --jump ${if}-in
	$IPTABLES --append INPUT --in-interface ${if} --jump ${if}-in
	new_chain ${if}-out
	$IPTABLES --append OUTPUT --out-interface ${if} --jump ${if}-out
	new_chain ${if}-forward-in
	$IPTABLES --append FORWARD --in-interface ${if} --jump ${if}-forward-in
	new_chain ${if}-forward-out
	$IPTABLES --append FORWARD --out-interface ${if} --jump ${if}-forward-out
	new_chain ${if}-postrouting-in
	#$IPTABLES --append POSTROUTING --in-interface ${if} --jump ${if}-postrouting-in
	. $i
done

for i in INPUT OUTPUT FORWARD; do
	$IPTABLES --append $i \
		-m limit --limit 5/s \
		--jump LOG \
		--log-prefix "End of ${i}:" 
done

echo -n Enabling IP forwarding...
echo 1 >/proc/sys/net/ipv4/ip_forward
echo Done

echo $IMPORTED


